import React, { FunctionComponent } from 'react';
import PropTypes from 'prop-types';
import SearchIcon from '@material-ui/icons/Search';
import { makeStyles, InputAdornment } from '@material-ui/core';
import { TextFieldProps } from '@material-ui/core/TextField';
import { useTranslate, InputProps } from 'ra-core';

import TextInput from './TextInput';

const useStyles = makeStyles({
    input: {
        marginTop: 32,
    },
});

const SearchInput: FunctionComponent<
    InputProps<TextFieldProps> & Omit<TextFieldProps, 'label' | 'helperText'>
> = ({ classes: classesOverride, ...props }) => {
    const translate = useTranslate();
    const classes = useStyles({ classes: classesOverride });

    return (
        <TextInput
            label={false}
            placeholder={translate('ra.action.search')}
            InputProps={{
                endAdornment: (
                    <InputAdornment position="end">
                        <SearchIcon color="disabled" />
                    </InputAdornment>
                ),
            }}
            className={classes.input}
            {...props}
        />
    );
};

SearchInput.propTypes = {
    classes: PropTypes.object,
};

export default SearchInput;
